<template>
  <j-modal
    :confirmLoading='confirmLoading'
    :okButtonProps="{ class:{'jee-hidden': disableSubmit} }"
    :title='title'
    :visible='visible'
    :width='800'
    cancelText='关闭'
    switchFullscreen
    @cancel='handleCancel'
    @ok='handleOk'>

    <a-spin :spinning='confirmLoading'>
      <a-form-model ref='form' :model='model' :rules='validatorRules'>
        <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='单据号' prop='code'>
          <a-input v-model='model.code' disabled placeholder='编码系统自动生成' />
        </a-form-model-item>
        <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='调出设备' prop='equipmentId'>
          <lx-search-equipment-select v-model='model.equipmentId'
                                      :disabled='disableSubmit'
                                      placeholder='请输入设备编号或名称搜索'></lx-search-equipment-select>
        </a-form-model-item>
        <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='处理类型' prop='scrapType'>
          <j-dict-select-tag v-model='model.scrapType' :disabled='disableSubmit || initialAcceptanceDisable' dictCode='scrap_sell'
                             placeholder='请选择处理类型' type='radio' />
        </a-form-model-item>
        <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='处置理由' prop='scrapReason'>
          <a-input v-model='model.scrapReason' placeholder='请输入处置理由' />
        </a-form-model-item>
        <div v-if='model.scrapType == 2'>
          <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='处置金额' prop='scrapAmount'>
            <a-input v-model='model.scrapAmount' placeholder='请输入处置金额' />
          </a-form-model-item>
        </div>
        <a-form-model-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='备注' prop='remark'>
          <a-textarea v-model='model.remark' :disabled='disableSubmit' placeholder='请输入备注' />
        </a-form-model-item>

      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { httpAction } from '@/api/manage'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'


export default {
  name: 'EamEquipmentScrapModal',
  components: { LxSearchEquipmentSelect },
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },

      confirmLoading: false,
      validatorRules: {
        scrapReason: [
          { required: true, message: '请输入处置原因！' }
        ],
        equipmentId: [
          { required: true, message: '请选择设备！' }
        ],
        transferReason: [
          { required: true, message: '请输入变动原因！' }
        ],
        scrapType: [
          { required: true, message: '请选择类型！' }
        ]
      },
      url: {
        add: '/eam/eamEquipmentScrap/add',
        edit: '/eam/eamEquipmentScrap/edit'
      }
    }
  },
  created() {
  },
  methods: {
    add() {
      //初始化默认值
      this.edit({})
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    }


  }
}
</script>

<style lang='less' scoped>

</style>